@@ -277,7 +277,7 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
         logger.info("AWS home=" + aws_home)
         generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand, app_name)
         if stack == 'core':
-            deploy_core(logger,app_name,api_stage,app_domain,brand,env,app_suffix,aws_profile,registry_url,tag)
+            deploy_core(logger,app_name,api_stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag)
         elif stack == 'biz-service':
             deploy_biz_services(logger,app_name,stage,app_domain,brand,env,app_suffix,aws_profile)
         elif stack == 'app-service':
